.. template documentation master file, created by
   sphinx-quickstart on Thu Sep 04 12:36:36 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to template's documentation!
====================================
Contents:

.. toctree::
   :maxdepth: 2

   conf.py
   codechat_config.yaml


Notes on use with the CodeChat System
-------------------------------------
Compared to a standard ``conf.py`` Sphinx configuration file generated by ``sphinx-quickstart``, the `conf.py` in this project:

-  Includes the CodeChat extension and associated settings; simply search for "CodeChat" in `conf.py` for more information.
-  The ``sphinx-build`` executable is provided with an output directory of ``_build`` (see `codechat_config.yaml`), which matches the output directory for the CodeChat system also specified in `codechat_config.yaml`.

To use these files, simply copy them to a new project directory of your choice. Open them in your preferred text editor/IDE, then use a appropriate CodeChat extension/plugin to open any of these files to build and view the results.

Indices and tables
------------------
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
